@@ -101,6 +101,7 @@ struct connection_data
 	GtkWidget		*vscrollbar;
   	gint             telnet_state;
   	gint             telnet_subneg;
+	gint             conn_id;
 };
 
 struct system_data {
@@ -157,6 +158,16 @@ struct _AutoMapConfig
 };
 #endif
 
+enum tray_status
+{
+        offline,
+        offline_connecting,
+        online,
+        online_connecting
+        // could use a few more
+};
+
+
 
 /*
  * Function declares
@@ -182,7 +193,7 @@ void		 open_connection (CONNECTION_DATA *);
 
 /* init.c */
 void		 main_window (void);
-void		 destroy (GtkWidget *);
+gboolean	 destroy (GtkWidget *);
 void		 close_window (GtkWidget *, gpointer);
 
 /* color.c */
@@ -253,4 +264,10 @@ void  terminal_feed   ( GtkWidget *, gchar *data                     );
 CONNECTION_DATA *create_connection_data ( gint notebook );
 void  free_connection_data (CONNECTION_DATA *c             );
 
+/* tray.c */
+void tray_create();
+void tray_destroy();
+void tray_menu();
+void tray_update_icon (enum tray_status icon);
+
 #endif /* __GNOME_MUD_H__ */
