@@ -30,7 +30,7 @@
 #include "gnome-mud.h"
 
 static char const rcsid[] = 
-	"$Id: init.c,v 1.91 2003/07/04 09:17:13 lobbin Exp $";
+	"$Id: init.c,v 1.101 2004/02/11 12:58:25 jordim Exp $";
 
 extern gchar        *host;
 extern gchar        *port;
@@ -41,11 +41,10 @@ CONNECTION_DATA *main_connection;
 CONNECTION_DATA *connections[MAX_CONNECTIONS];
 GtkWidget       *main_notebook;
 GtkWidget       *text_entry;
-/* FIXME
+
 #ifdef USE_PYGTK
 GtkWidget *box_user;
 #endif
-*/
 
 GtkWidget       *window;
 GList           *EntryHistory = NULL;
@@ -70,7 +69,7 @@ static gboolean dialog_close_cb(GtkWidget *widget, GdkEvent *event, gpointer dat
 	return TRUE;
 }
 
-void destroy (GtkWidget *widget)
+gboolean destroy (GtkWidget *widget)
 {
 	GtkWidget *dialog;
 	gint i, retval;
@@ -100,7 +99,7 @@ void destroy (GtkWidget *widget)
 		if (retval == GTK_RESPONSE_NO || retval == GTK_RESPONSE_DELETE_EVENT)
 		{
 			gtk_widget_destroy(dialog);
-			return;
+			return TRUE;
 		}
 	}
 
@@ -132,6 +131,8 @@ void destroy (GtkWidget *widget)
     }
   */  
 	gtk_main_quit ();
+	
+	return FALSE;
 }
 
 static void window_menu_file_connect (GtkWidget *widget, gpointer data)
@@ -201,6 +202,10 @@ static void window_menu_file_reconnect (GtkWidget *widget, gpointer data)
 {
 	CONNECTION_DATA *cd;
 	gint i;
+        GtkWidget		*label;
+        GtkWidget		*image = NULL;
+        GtkWidget		*box_label;
+
 
 	i = gtk_notebook_get_current_page (GTK_NOTEBOOK(main_notebook));
 	cd = connections[i];
@@ -217,6 +222,18 @@ static void window_menu_file_reconnect (GtkWidget *widget, gpointer data)
 	}
 
 	open_connection(cd);
+
+        if (cd->connected == TRUE) {
+                image = gtk_image_new_from_file(GMPIXMAPSDIR "/connection-online.png");
+                label = gtk_label_new(cd->host);
+
+                box_label = gtk_hbox_new (FALSE, 0);
+                gtk_box_pack_start (GTK_BOX (box_label), image, TRUE, TRUE, 0);
+                gtk_box_pack_start (GTK_BOX (box_label), label, FALSE, FALSE, 0);
+                gtk_widget_show_all(box_label);
+
+                gtk_notebook_set_tab_label(GTK_NOTEBOOK(main_notebook), gtk_notebook_get_nth_page(GTK_NOTEBOOK(main_notebook), i), box_label);
+        }
 } /* window_menu_file_reconnect */
 
 static void window_menu_help_about (GtkWidget *widget, gpointer data)
@@ -233,6 +250,11 @@ static void window_menu_help_about (GtkWidget *widget, gpointer data)
 		"Jordi Mallach <jordi@sindominio.net>",
 		"Petter E. Stokke <gibreel@project23.no>",
 		"Rachael Munns <vashti@dream.org.uk>",
+		"Adam Luchjenbroers <adam@luchjenbroers.com>",
+		"Nuno Sousa <nunofgs@punkass.com>",
+		"",
+		_("Artwork by:"),
+		"Daniel Taylor <dantaylor@web.de>",
 		NULL};
 	const char *documenters[] = {
 		"Jordi Mallach <jordi@sindominio.net>",
@@ -243,11 +265,10 @@ static void window_menu_help_about (GtkWidget *widget, gpointer data)
 	   * Paul Translator <paul@translator.org>         */
 	const char *translator_credits = _("translator_credits");
 
-	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/gnome-gmush.png", NULL);
+	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/gnome-mud.png", NULL);
   
 	about = gnome_about_new (_("GNOME-Mud"), VERSION,
-			   /* latin1 translators can use the copyright symbol here, see man latin1(7) */
-				 _("(C) 1998, 1999, 2000, 2001, 2002, 2003 Robin Ericsson"),
+				 "\xc2\xa9 1998-2004 Robin Ericsson",
 				 _("A Multi-User Dungeon (MUD) client for GNOME.\n"),
 				 authors,
 				 documenters,
@@ -489,6 +510,7 @@ static int text_entry_key_press_cb (GtkEntry *text_entry, GdkEventKey *event, gp
 CONNECTION_DATA *create_connection_data(gint notebook)
 {
 	CONNECTION_DATA *c;
+	struct timeval tv;
 
 	c = g_malloc0(sizeof(CONNECTION_DATA));
 #ifdef ENABLE_MCCP
@@ -500,6 +522,9 @@ CONNECTION_DATA *create_connection_data(gint notebook)
 	c->profile = profiledata_find("Default");
 	c->window = vte_terminal_new();
 
+	gettimeofday(&tv, NULL);
+	c->last_log_flush = tv.tv_sec;
+
 	vte_terminal_set_colors(VTE_TERMINAL(c->window), &prefs.Foreground, &prefs.Background, prefs.Colors, C_MAX);
 	vte_terminal_set_scrollback_lines(VTE_TERMINAL(c->window), prefs.Scrollback);
 	vte_terminal_set_scroll_on_output(VTE_TERMINAL(c->window), prefs.ScrollOnOutput);
@@ -529,9 +554,10 @@ void free_connection_data (CONNECTION_DATA *c)
 static void window_menu_file_close (GtkWidget *widget, gpointer data)
 {
 	CONNECTION_DATA *cd;
-	gint number, i;
+	gint number, i, tabs;
 
 	number = gtk_notebook_get_current_page (GTK_NOTEBOOK (main_notebook));
+        tabs = gtk_notebook_get_n_pages(GTK_NOTEBOOK(main_notebook));
 
 	cd = connections[number];
 
@@ -545,9 +571,12 @@ static void window_menu_file_close (GtkWidget *widget, gpointer data)
 		disconnect (NULL, cd);
 	}
 
-	if (cd != main_connection)
-	{
+        if (tabs > 1) {
 		gtk_notebook_remove_page (GTK_NOTEBOOK (main_notebook), number);
+                tabs--;
+                if (tabs == 1)
+                        gtk_notebook_set_show_tabs(GTK_NOTEBOOK(main_notebook), FALSE);
+
 
 		free_connection_data (cd);
 
@@ -556,6 +585,9 @@ static void window_menu_file_close (GtkWidget *widget, gpointer data)
 			int old = i++;
 			connections[old] = connections[i];
 		}
+
+                if (cd == main_connection)
+                       main_connection = connections[0];
 	}
 }
 
@@ -634,17 +666,17 @@ static void window_menu_plugin_api_manual_activate_cb(GtkMenuItem *menuitem)
 }
 
 static GnomeUIInfo toolbar_menu[] = {
-  GNOMEUIINFO_ITEM_STOCK(N_("Wizard..."), NULL, window_profiles,   GNOME_STOCK_PIXMAP_NEW),
+  GNOMEUIINFO_ITEM_STOCK(N_("Wizard..."), N_("Open the Connection Wizard"), window_profiles,   GNOME_STOCK_PIXMAP_NEW),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_ITEM_STOCK(N_("Profiles..."), NULL, window_profile_edit, GNOME_STOCK_PIXMAP_PREFERENCES),
+  GNOMEUIINFO_ITEM_STOCK(N_("Profiles..."), N_("Manage user profiles"), window_profile_edit, GNOME_STOCK_PIXMAP_PREFERENCES),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_ITEM_STOCK(N_("Connect..."), NULL, window_menu_file_connect, GNOME_STOCK_PIXMAP_OPEN),
+  GNOMEUIINFO_ITEM_STOCK(N_("Connect..."), N_("Connect to a mud"), window_menu_file_connect, GNOME_STOCK_PIXMAP_OPEN),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_ITEM_STOCK(N_("Disconnect"), NULL, window_menu_file_disconnect,  GNOME_STOCK_PIXMAP_CLOSE),
+  GNOMEUIINFO_ITEM_STOCK(N_("Disconnect"), N_("Disconnect from the mud"), window_menu_file_disconnect,  GNOME_STOCK_PIXMAP_CLOSE),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_ITEM_STOCK(N_("Reconnect"), NULL, window_menu_file_reconnect, GNOME_STOCK_PIXMAP_REFRESH),
+  GNOMEUIINFO_ITEM_STOCK(N_("Reconnect"), N_("Reconnect to the mud"), window_menu_file_reconnect, GNOME_STOCK_PIXMAP_REFRESH),
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_ITEM_STOCK(N_("Exit"), NULL, destroy, GNOME_STOCK_PIXMAP_EXIT),
+  GNOMEUIINFO_ITEM_STOCK(N_("Exit"), N_("Quit GNOME-Mud"), destroy, GNOME_STOCK_PIXMAP_EXIT),
   GNOMEUIINFO_END
 };
 
@@ -712,37 +744,48 @@ void main_window ()
 	GtkWidget *box_main;
 	GtkWidget *box_main2;
 	GtkWidget *box_h_low;
+        GtkWidget *box_label;
+        GtkWidget *image = NULL;
 	char  buf[1024];
   
 	window = gnome_app_new("gnome-mud", "GNOME Mud");
 	gtk_window_set_default_size(GTK_WINDOW(window), 500, 300);
 	gtk_widget_realize(window);
-	gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(destroy), NULL);
+	gtk_signal_connect(GTK_OBJECT(window), "delete-event", GTK_SIGNAL_FUNC(destroy), NULL);
   
 	box_main = gtk_vbox_new (FALSE, 0);
 	gnome_app_set_contents(GNOME_APP(window), box_main);
 	gnome_app_create_menus(GNOME_APP(window), main_menu);
 	gnome_app_create_toolbar(GNOME_APP(window), toolbar_menu);
 
-/* FIXME
 #ifdef USE_PYGTK
 	box_user = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (box_main), box_user, FALSE, FALSE, 0);
 #endif
-*/
   
 	box_main2 = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (box_main), box_main2, TRUE, TRUE, 5);
+	gtk_box_pack_start (GTK_BOX (box_main), box_main2, TRUE, TRUE, 1);
 
 	main_notebook = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(main_notebook), tab_location_by_gtk(prefs.TabLocation));
 	GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(main_notebook), GTK_CAN_FOCUS);
 	gtk_signal_connect (GTK_OBJECT (main_notebook), "switch-page", GTK_SIGNAL_FUNC (switch_page_cb), NULL);
-	gtk_box_pack_start (GTK_BOX (box_main2), main_notebook, TRUE, TRUE, 5);
-  
+	gtk_box_pack_start (GTK_BOX (box_main2), main_notebook, TRUE, TRUE, 1);
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(main_notebook), FALSE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(main_notebook), FALSE);
+
 	box_h_low = gtk_hbox_new (FALSE, 0);
+
+	image = gtk_image_new_from_file(GMPIXMAPSDIR "/connection-offline.png");
+	/* Do we really need this now? */
 	label = gtk_label_new (_("Main"));
-	gtk_notebook_append_page(GTK_NOTEBOOK(main_notebook), box_h_low, label);
+
+	box_label = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box_label), image, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (box_label), label, FALSE, FALSE, 0);
+	gtk_widget_show_all(box_label);
+
+	gtk_notebook_append_page(GTK_NOTEBOOK(main_notebook), box_h_low, box_label);
  
 	main_connection = create_connection_data(0);
 
@@ -750,6 +793,11 @@ void main_window ()
 	gtk_box_pack_start(GTK_BOX(box_h_low), main_connection->vscrollbar, FALSE, FALSE, 0);
 
 	text_entry = gtk_entry_new();
+	/* Need to fix the text entry cursor/text colour 
+	gtk_widget_modify_base(text_entry, GTK_STATE_NORMAL, &prefs.Background);
+	gtk_widget_modify_text(text_entry, GTK_STATE_NORMAL, &prefs.Foreground);
+	*/ 
+
 	if (EntryHistory != NULL)
 	{
 		// FIXME
@@ -762,14 +810,12 @@ void main_window ()
 	gtk_widget_grab_focus (text_entry);
   
 	gtk_widget_show_all (window);
+	tray_create();
+
 	vte_terminal_set_font_from_string(VTE_TERMINAL(main_connection->window), prefs.FontName);
  
 	g_snprintf(buf, 1023, _("GNOME-Mud version %s (compiled %s, %s)\n"), VERSION, __TIME__, __DATE__);
 	terminal_feed(main_connection->window, buf);
-	terminal_feed(main_connection->window, _("Distributed under the terms of the GNU General Public Licence.\n"));
-#ifdef USE_PYTHON
-  	g_snprintf(buf, 1023, _("\nPython version %s\n"), Py_GetVersion());
-	terminal_feed(main_connection->window, buf);
-#endif
+	terminal_feed(main_connection->window, _("Distributed under the terms of the GNU General Public License.\n"));
 }
 
