@@ -22,8 +22,8 @@
 
 #include <gconf/gconf-client.h>
 #include <gnome.h>
+#include <vte/vte.h>
 #include <stdio.h>
-#include <time.h>
 
 #include "gnome-mud.h"
 
@@ -110,7 +110,7 @@ void file_selection_cb_open
     t = time(&t) ;
     strftime(buf, 255, "Started logging %A %d %B %Y %H:%M:%S.\n\n",
       localtime(&t)) ;
-    fputs(buf, cd->log) ;
+    fputs(buf, cd->log);
 
     g_snprintf(buf, 255, _("*** Logging to %s.\n"), cd->log_filename) ;
     textfield_add(cd, buf, MESSAGE_SYSTEM) ;
@@ -170,7 +170,7 @@ void stop_logging_connection(CONNECTION_DATA *cn) {
     t = time(&t) ;
     strftime(buf, 255, "\nStopped logging %A %d %B %Y %H:%M:%S\n\n",
       localtime(&t)) ;
-    fputs(buf, cn->log) ;
+    fputs(buf, cn->log);
 
     fclose(cn->log) ;
     g_snprintf(buf, 255, _("*** Stopped logging to %s.\n"), cn->log_filename) ;
@@ -202,8 +202,7 @@ static void window_menu_file_save_log_file_ok_cb
 		return;
 	}
 
-	// FIXME, can't read this... (segfault)
-	textdata = gtk_editable_get_chars(GTK_EDITABLE(cd->window), 0, -1);	
+	textdata = vte_terminal_get_text (VTE_TERMINAL (cd->window), NULL, NULL, NULL);
 	fputs(textdata, fp);
 	g_free(textdata);
 
