@@ -25,7 +25,7 @@
 #include "gnome-mud.h"
 
 static char const rcsid[] =
-    "$Id: profiles.c,v 1.32 2003/06/24 14:55:47 jordim Exp $";
+    "$Id: profiles.c,v 1.38 2003/12/12 19:44:31 jordim Exp $";
 
 WIZARD_DATA2 *connections_find_by_profilename(gchar *name);
 gint 		  get_size(GtkCList *clist);
@@ -60,13 +60,13 @@ static void profile_gconf_sync_connection_list()
 	for (entry = g_list_first(Profiles); entry != NULL; entry = g_list_next(entry))
 	{
 		WIZARD_DATA2 *wd = (WIZARD_DATA2 *) entry->data;
-
+		
 		if (strlen(wd->playername) > 0)
 		{
 			gchar buf[1024];
 			
 			g_snprintf(buf, 1024, "%s-at-%s", wd->playername, wd->name);
-			list = g_slist_append(list, buf);
+			list = g_slist_append(list, g_strdup(buf));
 		}
 		else
 		{
@@ -75,20 +75,25 @@ static void profile_gconf_sync_connection_list()
 	}
 
 	gconf_client_set_list(gconf_client, "/apps/gnome-mud/connections/list", GCONF_VALUE_STRING, list, NULL);
+	g_slist_free(list);
 }
 
 static void profile_gconf_sync_wizard(WIZARD_DATA2 *wd)
 {
 	gchar buf[1024] = "";
+	gchar *cname, *pname;
 	gchar *bufn;
 
+	cname = gconf_escape_key(wd->name, -1);
+	pname = gconf_escape_key(wd->playername, -1);
+
 	if (strlen(wd->playername) > 0)
 	{
-		bufn = g_strdup_printf("%s-at-%s", wd->playername, wd->name);
+		bufn = g_strdup_printf("%s-at-%s", pname, cname);
 	}
 	else
 	{
-		bufn = g_strdup(wd->name);
+		bufn = g_strdup(cname);
 	}
 
 #define SYNC(Name, Value) \
@@ -104,6 +109,8 @@ static void profile_gconf_sync_wizard(WIZARD_DATA2 *wd)
 #undef SYNC
 
 	g_free(bufn);
+	g_free(pname);
+	g_free(cname);
 }
 
 static KEYBIND_DATA *profile_load_keybinds(gchar *profile_name)
@@ -175,16 +182,20 @@ void load_profiles()
 
 	for (entry = profiles; entry != NULL; entry = g_slist_next(entry))
 	{
+		gchar *pname;
 		PROFILE_DATA *pd = g_malloc0(sizeof(PROFILE_DATA));
 
 		pd->name = g_strdup((gchar *) entry->data);
-		pd->alias = profile_load_list(pd->name, "aliases");
-		pd->variables = profile_load_list(pd->name, "variables");
-		pd->triggers = profile_load_list(pd->name, "triggers" );
+		pname = gconf_escape_key(pd->name, -1);
+		pd->alias = profile_load_list(pname, "aliases");
+		pd->variables = profile_load_list(pname, "variables");
+		pd->triggers = profile_load_list(pname, "triggers" );
 
-		pd->kd = profile_load_keybinds(pd->name);
+		pd->kd = profile_load_keybinds(pname);
 	
 		ProfilesData = g_list_append(ProfilesData, (gpointer) pd);
+
+		g_free(pname);
 	}
 
 	/*
@@ -193,13 +204,16 @@ void load_profiles()
 	connections = gconf_client_get_list(gconf_client, "/apps/gnome-mud/connections/list", GCONF_VALUE_STRING, NULL);
 
 #define LOAD(Name, Value) \
-		g_snprintf(buf, 1024, "/apps/gnome-mud/connections/%s/%s", (gchar *) entry->data, Name); \
+		g_snprintf(buf, 1024, "/apps/gnome-mud/connections/%s/%s", wname, Name); \
 		Value = g_strdup(gconf_client_get_string(gconf_client, buf, NULL));
 
 	for (entry = connections; entry != NULL; entry = g_slist_next(entry))
 	{
 		WIZARD_DATA2 *wd = g_malloc0(sizeof(WIZARD_DATA2));
 		gchar buf[1024];
+		gchar *wname;
+
+		wname = gconf_escape_key((gchar *) entry->data, -1);
 	
 		LOAD("name", wd->name);
 		LOAD("hostname", wd->hostname);
@@ -209,6 +223,8 @@ void load_profiles()
 		LOAD("profile", wd->profile);
 		
 		Profiles = g_list_append(Profiles, (gpointer) wd);
+
+		g_free(wname);
 	}
 
 #undef LOAD
@@ -234,6 +250,7 @@ static void profilelist_new_profile(const gchar *string, gpointer data)
 	GList *t;
 	PROFILE_DATA *pd;
 	gchar *pdir, *key, *text[2];
+	gchar *pname = gconf_escape_key(string, -1);
 
 	if (string == NULL)
 	{
@@ -248,7 +265,7 @@ static void profilelist_new_profile(const gchar *string, gpointer data)
 		}
 	}
 
-	pdir = gconf_concat_dir_and_key("/apps/gnome-mud/profiles", string);
+	pdir = gconf_concat_dir_and_key("/apps/gnome-mud/profiles", pname);
 
 #define SET_LIST(name) \
 	key = gconf_concat_dir_and_key(pdir, name); \
@@ -271,6 +288,7 @@ static void profilelist_new_profile(const gchar *string, gpointer data)
 
 	g_free(text[0]);
 	g_free(pdir);
+	g_free(pname);
 }
 
 static void profilelist_new_cb(GtkWidget *widget, gpointer data)
@@ -464,14 +482,6 @@ static void profilelist_clist_fill(PROFILE_DATA *pd, GtkCList *clist)
 	gtk_clist_append(clist, text);
 }
 
-static void profilelist_cleanup (GtkWidget *widget, GtkWidget *data)
-{
-	if (GTK_IS_WIDGET(data))
-	{
-		gtk_widget_destroy(data);
-	}
-}
-
 static void profilelist_dialog (GtkWidget *label)
 {
 	static GtkWidget *dialog;
@@ -545,7 +555,6 @@ static void profilelist_dialog (GtkWidget *label)
 	gtk_signal_connect_object(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), (gpointer) dialog);
 	gtk_signal_connect_object(GTK_OBJECT(button_cancel), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), (gpointer) dialog);
 
-	gtk_signal_connect(GTK_OBJECT(label->parent->parent), "destroy", GTK_SIGNAL_FUNC(profilelist_cleanup), (gpointer) dialog);
 	gtk_signal_connect(GTK_OBJECT(dialog), "destroy", GTK_SIGNAL_FUNC(gtk_widget_destroyed), &dialog);
 	
 	gtk_widget_show(dialog);
@@ -772,7 +781,7 @@ static gboolean connections_button_press_cb(GtkWidget *widget, GdkEventButton *e
 	{
 		case GDK_2BUTTON_PRESS:
 			gtk_clist_get_selection_info(GTK_CLIST(widget), event->x, event->y, &row, &col);
-			if (gtk_clist_get_text(GTK_CLIST(widget), row, col, &row_name))
+			if (gtk_clist_get_text(GTK_CLIST(widget), row, 0, &row_name))
 			{
 				WIZARD_DATA2 *wd;
 				CONNECTION_DATA *cd;
@@ -900,6 +909,7 @@ void window_profiles(void)
 	gtk_widget_show (label1);
 	gtk_clist_set_column_widget (GTK_CLIST (main_clist), 0, label1);
 
+	/* Translators: this is the name of your player */
 	label2 = gtk_label_new (_("Character"));
 	gtk_widget_ref (label2);
 	gtk_object_set_data_full (GTK_OBJECT (dialog), "label2", label2, (GtkDestroyNotify) gtk_widget_unref);
@@ -913,7 +923,7 @@ void window_profiles(void)
 	gtk_widget_show (main_vbox);
 	gtk_box_pack_start (GTK_BOX (main_hbox), main_vbox, TRUE, TRUE, 0);
 
-	frame_info_mud = gtk_frame_new (_(" Mud Information "));
+	frame_info_mud = gtk_frame_new (_("Mud information"));
 	gtk_widget_ref (frame_info_mud);
 	gtk_object_set_data_full (GTK_OBJECT (dialog), "frame_info_mud", frame_info_mud, (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (frame_info_mud);
@@ -973,7 +983,7 @@ void window_profiles(void)
 	gtk_widget_set_usize (entry_info_mud_port, 40, -2);
 	gtk_signal_connect(GTK_OBJECT(entry_info_mud_port), "insert-text", GTK_SIGNAL_FUNC(connections_entry_info_mud_port_cb), NULL);
 			
-	frame_info_char = gtk_frame_new (_(" Character Information "));
+	frame_info_char = gtk_frame_new (_("Character information"));
 	gtk_widget_ref (frame_info_char);
 	gtk_object_set_data_full (GTK_OBJECT (dialog), "frame_info_char", frame_info_char, (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (frame_info_char);
@@ -1018,7 +1028,7 @@ void window_profiles(void)
 	gtk_table_attach (GTK_TABLE (table2), entry_info_char_password, 1, 2, 1, 2, (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	gtk_entry_set_visibility(GTK_ENTRY(entry_info_char_password), FALSE);
 
-	frame_info_prof = gtk_frame_new (_(" Profile Information "));
+	frame_info_prof = gtk_frame_new (_("Profile information"));
 	gtk_widget_ref (frame_info_prof);
 	gtk_object_set_data_full (GTK_OBJECT (dialog), "frame_info_prof", frame_info_prof, (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show (frame_info_prof);
@@ -1230,7 +1240,7 @@ void window_profile_edit(void)
 	 * Button keybinds
 	 */
 	tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-select-font", GTK_ICON_SIZE_LARGE_TOOLBAR);
-	button_keybinds = gtk_toolbar_append_item (GTK_TOOLBAR(toolbar), _("Keybinds"), _("Set keybinds"), NULL, tmp_toolbar_icon, NULL, NULL);
+	button_keybinds = gtk_toolbar_append_item (GTK_TOOLBAR(toolbar), _("Keybindings"), _("Set keybindings"), NULL, tmp_toolbar_icon, NULL, NULL);
 	gtk_widget_show(button_keybinds);
 
 	/*
